
Welcome to ``pqp``'s documentation!
=======================================

``pqp`` (short for *pourquoi pas?*) provides tools for creating, visualizing, and performing inference on causal graphical models. The package aims to facilitate causal understanding for data scientists and researchers by providing an intuitive API built on top of performant and correct implementations of the underlying algorithms.

Getting Started
-----------------

.. toctree::
   :maxdepth: 1

   quickstart

Modules
-------

.. toctree::
    :maxdepth: 1

    module_maps/data
    module_maps/estimation
    module_maps/identification
    module_maps/refutation
    module_maps/symbols
    module_maps/utils
    module_maps/exceptions

Site Navigation
~~~~~~~~~~~~~~~~~~

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
